@@ -55,6 +55,7 @@ module Pipes.ByteString (
     , stdin
     , fromHandle
     , hGetSome
+    , hGetNonBlocking
     , hGet
     , hGetRange
 
@@ -225,6 +226,23 @@ hGetSome size h = go
                 go
 {-# INLINABLE hGetSome #-}
 
+{-| Convert a handle into a byte stream using a fixed chunk size
+
+    Similar to 'hGet' except that it will never block waiting for data
+    to become available.
+-}
+hGetNonBlocking :: MonadIO m => Int -> IO.Handle -> Producer' ByteString m ()
+hGetNonBlocking size h = go where
+    go = do
+        eof <- liftIO (IO.hIsEOF h)
+        if eof
+            then return ()
+            else do
+                bs <- liftIO (BS.hGetNonBlocking h size)
+                yield bs
+                go
+{-# INLINABLE hGetNonBlocking #-}
+
 {-| Convert a handle into a byte stream using a fixed chunk size
 
     'hGet' waits until exactly the requested number of bytes are available for
@@ -1001,8 +1019,6 @@ unwords = PG.intercalates (yield $ BS.singleton $ fromIntegral $ ord ' ')
 {- $reexports
     @Data.ByteString@ re-exports the 'ByteString' type.
 
-    @Data.Profunctor@ re-exports the 'Profunctor' type.
-
     @Data.Word@ re-exports the 'Word8' type.
 
     @Pipes.Parse@ re-exports 'Parser'.
